Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(26)

Unified Diff: tests/dartino_tests/messages.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/dartino_tests/message_tests.dart ('k') | tests/dartino_tests/multiprogram_tests.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/dartino_tests/messages.dart
diff --git a/tests/fletch_tests/messages.dart b/tests/dartino_tests/messages.dart
similarity index 95%
rename from tests/fletch_tests/messages.dart
rename to tests/dartino_tests/messages.dart
index 61067635510f4793b60989743205788ae447f4dc..9898ccf5a4ecaaa9187fe2a0a3c3450886d06251 100644
--- a/tests/fletch_tests/messages.dart
+++ b/tests/dartino_tests/messages.dart
@@ -2,8 +2,8 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-/// Messages used by fletch_test_suite.dart to communicate with test.py.
-library fletch_tests.messages;
+/// Messages used by dartino_test_suite.dart to communicate with test.py.
+library dartino_tests.messages;
import 'dart:convert' show
JSON;
@@ -146,8 +146,8 @@ class RunTest extends NamedMessage {
/// Notify that test [name] timed out.
///
/// This message is bi-directional, it is used by test.dart to tell
/// fletch_test_suite.dart that a test has timed out, as well as by
/// fletch_test_suite.dart to tell test.dart that the test did in fact time out
/// (due to interprocess communication, and lack of synchronization, it is
/// possible for a test to complete normally before it is terminated).
class TimedOut extends NamedMessage {
@@ -146,8 +146,8 @@ class RunTest extends NamedMessage {
///
/// This message is bi-directional, it is used by test.dart to tell
-/// fletch_test_suite.dart that a test has timed out, as well as by
-/// fletch_test_suite.dart to tell test.dart that the test did in fact time out
+/// dartino_test_suite.dart that a test has timed out, as well as by
+/// dartino_test_suite.dart to tell test.dart that the test did in fact time out
/// (due to interprocess communication, and lack of synchronization, it is
/// possible for a test to complete normally before it is terminated).
« no previous file with comments | « tests/dartino_tests/message_tests.dart ('k') | tests/dartino_tests/multiprogram_tests.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698